<?php

namespace Ebuy\Restaurant\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Ebuy\Restaurant\Http\Requests\RestaurantRequest;
use Ebuy\Restaurant\Interfaces\RestaurantRepositoryInterface;
use Ebuy\Restaurant\Models\Restaurant;
use Ebuy\Restaurant\Forms\Restaurant as Form;

/**
 * APIController  class for restaurant.
 */
class RestaurantAPIController extends BaseController
{

    /**
     * Initialize restaurant resource controller.
     *
     * @param type RestaurantRepositoryInterface $restaurant
     *
     * @return null
     */
    public function __construct(RestaurantRepositoryInterface $restaurant)
    {
        parent::__construct();
        $this->repository = $restaurant;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Ebuy\Restaurant\Repositories\Criteria\RestaurantResourceCriteria::class);
    }

    /**
     * Display a list of restaurant.
     *
     * @return Response
     */
    public function index(RestaurantRequest $request)
    {
        return $this->repository
            ->setPresenter(\Ebuy\Restaurant\Repositories\Presenter\RestaurantPresenter::class)
            ->paginate();
    }

    /**
     * Display restaurant.
     *
     * @param Request $request
     * @param Model   $restaurant
     *
     * @return Response
     */
    public function show(RestaurantRequest $request, Restaurant $restaurant)
    {
        return $restaurant->setPresenter(\Ebuy\Restaurant\Repositories\Presenter\RestaurantListPresenter::class);
        ;
    }

    /**
     * Create new restaurant.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RestaurantRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('restaurant::restaurant.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('restaurant/restaurant/' . $restaurant->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('restaurant/restaurant');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the restaurant.
     *
     * @param Request $request
     * @param Model   $restaurant
     *
     * @return Response
     */
    public function update(RestaurantRequest $request, Restaurant $restaurant)
    {
        try {
            $data = $request->all();

            $restaurant->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('restaurant::restaurant.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('restaurant/restaurant/' . $restaurant->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('restaurant/restaurant/' . $restaurant->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the restaurant.
     *
     * @param Model   $restaurant
     *
     * @return Response
     */
    public function destroy(RestaurantRequest $request, Restaurant $restaurant)
    {
        try {
            $restaurant->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('restaurant::restaurant.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('restaurant/restaurant/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('restaurant/restaurant/' . $restaurant->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
